Gompertz distribution
gompertz.RdDensity, distribution function, quantile function, and random generation for the Gompertz distribution.
Usage
dgompertz(x, eta = 1, b = 1, log = FALSE)
pgompertz(q, eta = 1, b = 1, lower.tail = TRUE, log.p = FALSE)
qgompertz(p, eta = 1, b = 1, lower.tail = TRUE, log.p = FALSE)
rgompertz(n, eta = 1, b = 1)Arguments
- x, q
vector of quantiles (non-negative)
- eta
shape parameter, must be positive
- b
rate parameter, must be positive
- log, log.p
logical; if
TRUE, probabilities/densities are returned as \(\log(p)\).- lower.tail
logical; if
TRUE(default), probabilities are \(P[X \le x]\), otherwise \(P[X > x]\).- p
vector of probabilities
- n
number of random values to return
Value
dgompertz gives the density, pgompertz gives the distribution function,
qgompertz gives the quantile function, and rgompertz generates random deviates.