| invgauss | R Documentation |
Density, distribution function, and random generation for the inverse Gaussian distribution.
dinvgauss(x, mean = 1, shape = 1, log = FALSE)
pinvgauss(q, mean = 1, shape = 1, lower.tail = TRUE, log.p = FALSE)
qinvgauss(p, mean = 1, shape = 1, lower.tail = TRUE, log.p = FALSE, ...)
rinvgauss(n, mean = 1, shape = 1)
x, q |
vector of quantiles, must be positive. |
mean |
location parameter |
shape |
shape parameter, must be positive. |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities |
... |
additional parameter passed to |
n |
number of random values to return |
This implementation of dinvgauss allows for automatic differentiation with RTMB.
qinvgauss and rinvgauss are imported from the statmod package.
dinvgauss gives the density, pinvgauss gives the distribution function, qinvgauss gives the quantile function, and rinvgauss generates random deviates.
x <- rinvgauss(1, 1, 0.5)
d <- dinvgauss(x, 1, 0.5)
p <- pinvgauss(x, 1, 0.5)
q <- qinvgauss(p, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.