| laplace | R Documentation |
Density, distribution function, quantile function, and random generation for the Laplace distribution.
dlaplace(x, mu = 0, b = 1, eps = NULL, log = FALSE)
plaplace(q, mu = 0, b = 1, lower.tail = TRUE, log.p = FALSE)
qlaplace(p, mu = 0, b = 1, lower.tail = TRUE, log.p = FALSE)
rlaplace(n, mu = 0, b = 1)
x, q |
vector of quantiles |
mu |
location parameter |
b |
scale parameter, must be positive. |
eps |
optional smoothing parameter for |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities |
n |
number of random values to return |
This implementation of dlaplace allows for automatic differentiation with RTMB.
dlaplace gives the density, plaplace gives the distribution function, qlaplace gives the quantile function, and rlaplace generates random deviates.
x <- rlaplace(1, 1, 1)
d <- dlaplace(x, 1, 1)
p <- plaplace(x, 1, 1)
q <- qlaplace(p, 1, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.