| trunct | R Documentation |
Density, distribution function, quantile function, and random generation for the truncated t distribution.
dtrunct(x, df, min = -Inf, max = Inf, log = FALSE)
ptrunct(q, df, min = -Inf, max = Inf, lower.tail = TRUE, log.p = FALSE)
qtrunct(p, df, min = -Inf, max = Inf, lower.tail = TRUE, log.p = FALSE)
rtrunct(n, df, min = -Inf, max = Inf)
x, q |
vector of quantiles |
df |
degrees of freedom parameter, must be positive. |
min, max |
truncation bounds. |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities |
n |
number of random values to return. |
This implementation of dtrunct allows for automatic differentiation with RTMB.
dtrunct gives the density, ptrunct gives the distribution function,
qtrunct gives the quantile function, and rtrunct generates random deviates.
x <- rtrunct(1, df = 5, min = -1, max = 5)
d <- dtrunct(x, df = 5, min = -1, max = 5)
p <- ptrunct(x, df = 5, min = -1, max = 5)
q <- qtrunct(p, df = 5, min = -1, max = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.