| zipois | R Documentation |
Probability mass function, distribution function, and random generation for the zero-inflated Poisson distribution.
dzipois(x, lambda, zeroprob = 0, log = FALSE)
pzipois(q, lambda, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzipois(n, lambda, zeroprob = 0)
x, q |
integer vector of counts |
lambda |
vector of (non-negative) means |
zeroprob |
zero-inflation probability between 0 and 1 |
log, log.p |
logical; return log-density if TRUE |
lower.tail |
logical; if |
n |
number of random values to return. |
This implementation allows for automatic differentiation with RTMB.
dzipois gives the probability mass function, pzipois gives the distribution function, and rzipois generates random deviates.
set.seed(123)
x <- rzipois(1, 0.5, 1)
d <- dzipois(x, 0.5, 1)
p <- pzipois(x, 0.5, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.