Learn R Programming

RTMBdist (version 1.0.1)

betabinom: Beta-binomial distribution

Description

Density and random generation for the beta-binomial distribution.

Usage

dbetabinom(x, size, shape1, shape2, log = FALSE)

rbetabinom(n, size, shape1, shape2)

Value

dbetabinom gives the density and rbetabinom generates random samples.

Arguments

x

vector of non-negative counts.

size

vector of total counts (number of trials). Needs to be >= x.

shape1

positive shape parameter 1 of the Beta prior.

shape2

positive shape parameter 2 of the Beta prior.

log

logical; if TRUE, densities are returned on the log scale.

n

number of random values to return (for rbetabinom).

Details

This implementation of dbetabinom allows for automatic differentiation with RTMB.

Examples

Run this code
set.seed(123)
x <- rbetabinom(1, 10, 2, 5)
d <- dbetabinom(x, 10, 2, 5)

Run the code above in your browser using DataLab