| betaprime | R Documentation |
Density, distribution function, quantile function, and random generation for the Beta prime distribution.
dbetaprime(x, shape1, shape2, log = FALSE)
pbetaprime(q, shape1, shape2, lower.tail = TRUE, log.p = FALSE)
qbetaprime(p, shape1, shape2, lower.tail = TRUE, log.p = FALSE)
rbetaprime(n, shape1, shape2)
x, q |
vector of quantiles |
shape1, shape2 |
non-negative shape parameters of the corresponding Beta distribution |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities |
n |
number of random values to return. |
This implementation allows for automatic differentiation with RTMB.
If X \sim \text{Beta}(\alpha, \beta), then \frac{X}{1-X} \sim \text{Betaprime}(\alpha, \beta)
dbetaprime gives the density, pbetaprime gives the distribution function, qbetaprime gives the quantile function, and rbetaprime generates random deviates.
x <- rbetaprime(1, 2, 1)
d <- dbetaprime(x, 2, 1)
p <- pbetaprime(x, 2, 1)
q <- qbetaprime(p, 2, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.