Gumbel copula constructors
cgumbel.RdConstruct functions that compute either the log density or the CDF
of the bivariate Gumbel copula, intended for use with dcopula.
Value
A function of two arguments (u, v) returning either
the log copula density (cgumbel) or the copula CDF (Cgumbel).
Details
The Gumbel copula density
$$ c(u,v;\theta) = \frac{e^{-A}}{uv} \, (\tilde u \tilde v)^{\theta - 1} S^{1/\theta - 2} (A + \theta - 1), $$ where \(\tilde u = -\log u\), \(\tilde v = -\log v\), \(S = \tilde u^\theta + \tilde v^\theta\) and \(A = S^{1/\theta}\), so that \(e^{-A}\) is the copula CDF.