| cgumbel | R Documentation |
Construct functions that compute either the log density or the CDF
of the bivariate Gumbel copula, intended for use with dcopula.
cgumbel(theta)
Cgumbel(theta)
theta |
Dependence parameter ( |
The Gumbel copula density
c(u,v;\theta) = \exp\Big[-\big((-\log u)^\theta + (-\log v)^\theta\big)^{1/\theta}\Big] \cdot h(u,v;\theta),
where h(u,v;\theta) contains the derivative terms ensuring the function is a density.
A function of two arguments (u, v) returning either
the log copula density (cgumbel) or the copula CDF (Cgumbel).
cgaussian(), cclayton(), cfrank()
x <- c(0.5, 1); y <- c(0.2, 0.4)
d1 <- dnorm(x, 1, log = TRUE); d2 <- dbeta(y, 2, 1, log = TRUE)
p1 <- pnorm(x, 1); p2 <- pbeta(y, 2, 1)
dcopula(d1, d2, p1, p2, copula = cgumbel(1.5), log = TRUE)
# CDF version (for discrete copulas)
Cgumbel(1.5)(0.5, 0.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.