Learn R Programming

RTMBdist (version 0.1.0)

cgumbel: Gumbel copula constructor

Description

Returns a function that computes the log density of the bivariate Gumbel copula, intended to be used with dcopula.

Usage

cgumbel(theta)

Value

A function of two arguments (u,v) returning log copula density.

Arguments

theta

Dependence parameter (\(\theta >= 1\)).

Details

The Gumbel copula density

$$ c(u,v;\theta) = \exp\Big[-\big((-\log u)^\theta + (-\log v)^\theta\big)^{1/\theta}\Big] \cdot h(u,v;\theta), $$ where \(h(u,v;\theta)\) contains the derivative terms ensuring the function is a density.

See Also

cgaussian(), cclayton(), cfrank()

Examples

Run this code
x <- c(0.5, 1); y <- c(0.2, 0.4)
d1 <- dnorm(x, 1, log = TRUE); d2 <- dbeta(y, 2, 1, log = TRUE)
p1 <- pnorm(x, 1); p2 <- pbeta(y, 2, 1)
dcopula(d1, d2, p1, p2, copula = cgumbel(1.5), log = TRUE)

Run the code above in your browser using DataLab