Returns a function that computes the log density of the bivariate Gumbel copula,
intended to be used with dcopula.
Usage
cgumbel(theta)
Value
A function of two arguments (u,v) returning log copula density.
Arguments
theta
Dependence parameter (\(\theta >= 1\)).
Details
The Gumbel copula density
$$
c(u,v;\theta) = \exp\Big[-\big((-\log u)^\theta + (-\log v)^\theta\big)^{1/\theta}\Big] \cdot h(u,v;\theta),
$$
where \(h(u,v;\theta)\) contains the derivative terms ensuring the function is a density.