Generalised Gamma distribution (GG)
gengamma.RdDensity, distribution function, quantile function, and random generation for the generalised Gamma distribution.
Usage
dgengamma(x, mu = 1, sigma = 0.5, nu = 1, log = FALSE)
pgengamma(q, mu = 1, sigma = 0.5, nu = 1, lower.tail = TRUE, log.p = FALSE)
qgengamma(p, mu = 1, sigma = 0.5, nu = 1, lower.tail = TRUE, log.p = FALSE)
rgengamma(n, mu = 1, sigma = 0.5, nu = 1)Arguments
- x, q
vector of quantiles
- mu
location parameter, must be positive.
- sigma
scale parameter, must be positive.
- nu
skewness parameter (real).
- log, log.p
logical; if
TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).- lower.tail
logical; if
TRUE(default), probabilities are \(P[X \le x]\), otherwise \(P[X > x]\).- p
vector of probabilities
- n
number of random values to return
Value
dgengamma gives the density, pgengamma gives the distribution function, qgengamma gives the quantile function, and rgengamma generates random deviates.
Details
This implementation of dgengamma, pgengamma, and qgengamma allows for automatic differentiation with RTMB.