dgenpois gives the probability mass function, pgenpois gives the distribution function, qgenpois gives the quantile function, and rgenpois generates random deviates.
Arguments
x, q
integer vector of counts
lambda
vector of positive means
phi
vector of non-negative dispersion parameters
log, log.p
logical; return log-density if TRUE
lower.tail
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
p
vector of probabilities
max.value
a constant, set to the default value of 10000 for how far the algorithm should look for q.
n
number of random values to return.
Details
This implementation of dgenpois allows for automatic differentiation with RTMB.
The other functions are imported from gamlss.dist::GPO.
The distribution has mean \(\lambda\) and variance \(\lambda(1 + \phi \lambda)^2\).
For \(\phi = 0\) it reduces to the Poisson distribution, however \(\phi\) must be strictly positive here.