powered by
Density, distribution function, quantile function, and random generation for the Gumbel distribution.
dgumbel(x, location = 0, scale = 1, log = FALSE)pgumbel(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)qgumbel(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)rgumbel(n, location = 0, scale = 1)
pgumbel(q, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
qgumbel(p, location = 0, scale = 1, lower.tail = TRUE, log.p = FALSE)
rgumbel(n, location = 0, scale = 1)
dgumbel gives the density, pgumbel gives the distribution function, qgumbel gives the quantile function, and rgumbel generates random deviates.
dgumbel
pgumbel
qgumbel
rgumbel
vector of quantiles
location parameter
scale parameter, must be positive.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
vector of probabilities
number of random values to return
This implementation of dgumbel allows for automatic differentiation with RTMB.
RTMB
x <- rgumbel(1, 0.5, 2) d <- dgumbel(x, 0.5, 2) p <- pgumbel(x, 0.5, 2) q <- qgumbel(p, 0.5, 2)
Run the code above in your browser using DataLab