| kumar | R Documentation |
Density, distribution function, quantile function, and random generation for the Kumaraswamy distribution.
dkumar(x, a, b, log = FALSE)
pkumar(q, a, b, lower.tail = TRUE, log.p = FALSE)
qkumar(p, a, b, lower.tail = TRUE, log.p = FALSE)
rkumar(n, a, b)
x, q |
vector of quantiles in |
a, b |
positive shape parameters |
log, log.p |
logical; if |
lower.tail |
logical; if |
p |
vector of probabilities |
n |
number of random values to return. |
dkumar gives the density, pkumar gives the distribution function, qkumar gives the quantile function, and rkumar generates random deviates.
x <- rkumar(1, a = 1, b = 2)
d <- dkumar(x, a = 1, b = 2)
p <- pkumar(x, a = 1, b = 2)
q <- qkumar(p, a = 1, b = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.