| oibeta | R Documentation |
Density, distribution function, and random generation for the one-inflated beta distribution.
doibeta(x, shape1, shape2, oneprob = 0, log = FALSE)
poibeta(q, shape1, shape2, oneprob = 0, lower.tail = TRUE, log.p = FALSE)
roibeta(n, shape1, shape2, oneprob = 0)
x, q |
vector of quantiles |
shape1, shape2 |
non-negative shape parameters of the beta distribution |
oneprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return. |
This implementation allows for automatic differentiation with RTMB.
doibeta gives the density, poibeta gives the distribution function, and roibeta generates random deviates.
set.seed(123)
x <- roibeta(1, 2, 2, 0.5)
d <- doibeta(x, 2, 2, 0.5)
p <- poibeta(x, 2, 2, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.