powered by
Density, distribution function, and random generation for the one-inflated beta distribution.
doibeta(x, shape1, shape2, oneprob = 0, log = FALSE)poibeta(q, shape1, shape2, oneprob = 0, lower.tail = TRUE, log.p = FALSE)roibeta(n, shape1, shape2, oneprob = 0)
poibeta(q, shape1, shape2, oneprob = 0, lower.tail = TRUE, log.p = FALSE)
roibeta(n, shape1, shape2, oneprob = 0)
doibeta gives the density, poibeta gives the distribution function, and roibeta generates random deviates.
doibeta
poibeta
roibeta
vector of quantiles
non-negative shape parameters of the beta distribution
zero-inflation probability between 0 and 1.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
number of random values to return.
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- roibeta(1, 2, 2, 0.5) d <- doibeta(x, 2, 2, 0.5) p <- poibeta(x, 2, 2, 0.5)
Run the code above in your browser using DataLab