powered by
Density, distribution function, and random generation for the one-inflated beta distribution reparameterised in terms of mean and concentration.
doibeta2(x, mu, phi, oneprob = 0, log = FALSE)poibeta2(q, mu, phi, oneprob = 0, lower.tail = TRUE, log.p = FALSE)roibeta2(n, mu, phi, oneprob = 0)
poibeta2(q, mu, phi, oneprob = 0, lower.tail = TRUE, log.p = FALSE)
roibeta2(n, mu, phi, oneprob = 0)
doibeta2 gives the density, poibeta2 gives the distribution function, and roibeta2 generates random deviates.
doibeta2
poibeta2
roibeta2
vector of quantiles
mean parameter, must be in the interval from 0 to 1.
concentration parameter, must be positive.
zero-inflation probability between 0 and 1.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
number of random values to return.
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- roibeta2(1, 0.6, 2, 0.5) d <- doibeta2(x, 0.6, 2, 0.5) p <- poibeta2(x, 0.6, 2, 0.5)
Run the code above in your browser using DataLab