| skewnorm | R Documentation |
Density, distribution function, quantile function, and random generation for the skew normal distribution.
dskewnorm(x, xi = 0, omega = 1, alpha = 0, log = FALSE)
pskewnorm(q, xi = 0, omega = 1, alpha = 0, ...)
qskewnorm(p, xi = 0, omega = 1, alpha = 0, ...)
rskewnorm(n, xi = 0, omega = 1, alpha = 0)
x, q |
vector of quantiles |
xi |
location parameter |
omega |
scale parameter, must be positive. |
alpha |
skewness parameter, +/- |
log |
logical; if |
... |
additional parameters to be passed to the |
p |
vector of probabilities |
n |
number of random values to return |
This implementation of dskewnorm allows for automatic differentiation with RTMB while the other functions are imported from the sn package.
See sn::dsn for more details.
dskewnorm gives the density, pskewnorm gives the distribution function, qskewnorm gives the quantile function, and rskewnorm generates random deviates.
skewnorm2, skewt, skewt2
# alpha is skew parameter
x <- rskewnorm(1, alpha = 1)
d <- dskewnorm(x, alpha = 1)
p <- pskewnorm(x, alpha = 1)
q <- qskewnorm(p, alpha = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.