dskewnorm gives the density, pskewnorm gives the distribution function, qskewnorm gives the quantile function, and rskewnorm generates random deviates.
Arguments
x, q
vector of quantiles
xi
location parameter
omega
scale parameter, must be positive.
alpha
skewness parameter, +/- Inf is allowed.
log
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
...
additional parameters to be passed to the sn package functions for pskewnorm and qskewnorm.
p
vector of probabilities
n
number of random values to return
Details
This implementation of dskewnorm allows for automatic differentiation with RTMB while the other functions are imported from the sn package.
See sn::dsn for more details.