| skewnorm2 | R Documentation |
Density, distribution function, quantile function and random generation for the skew normal distribution reparameterised in terms of mean, standard deviation and skew magnitude
dskewnorm2(x, mean = 0, sd = 1, alpha = 0, log = FALSE)
pskewnorm2(q, mean = 0, sd = 1, alpha = 0, ...)
qskewnorm2(p, mean = 0, sd = 1, alpha = 0, ...)
rskewnorm2(n, mean = 0, sd = 1, alpha = 0)
x, q |
vector of quantiles |
mean |
mean parameter |
sd |
standard deviation, must be positive. |
alpha |
skewness parameter, +/- |
log |
logical; if |
... |
additional parameters to be passed to the |
p |
vector of probabilities |
n |
number of random values to return |
This implementation of dskewnorm2 allows for automatic differentiation with RTMB while the other functions are imported from the sn package.
dskewnorm2 gives the density, pskewnorm2 gives the distribution function, qskewnorm2 gives the quantile function, and rskewnorm2 generates random deviates.
skewnorm, skewt, skewt2
# alpha is skew parameter
x <- rskewnorm2(1, alpha = 1)
d <- dskewnorm2(x, alpha = 1)
p <- pskewnorm2(x, alpha = 1)
q <- qskewnorm2(p, alpha = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.