skewnorm2: Reparameterised skew normal distribution
Description
Density, distribution function, quantile function and random generation for
the skew normal distribution reparameterised in terms of mean, standard deviation and skew magnitude
dskewnorm2 gives the density, pskewnorm2 gives the distribution function, qskewnorm2 gives the quantile function, and rskewnorm2 generates random deviates.
Arguments
x, q
vector of quantiles
mean
mean parameter
sd
standard deviation, must be positive.
alpha
skewness parameter, +/- Inf is allowed.
log
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
...
additional parameters to be passed to the sn package functions for pskewnorm and qskewnorm.
p
vector of probabilities
n
number of random values to return
Details
This implementation of dskewnorm2 allows for automatic differentiation with RTMB while the other functions are imported from the sn package.