Skip to contents

Density, distribution function, quantile function, and random generation for the t distribution with location and scale parameters.

Usage

dt2(x, mu, sigma, df, log = FALSE)

pt2(q, mu, sigma, df, lower.tail = TRUE, log.p = FALSE)

rt2(n, mu, sigma, df)

qt2(p, mu, sigma, df, lower.tail = TRUE, log.p = FALSE)

pt(q, df)

Arguments

x, q

vector of quantiles

mu

location parameter

sigma

scale parameter, must be positive.

df

degrees of freedom, must be positive.

log, log.p

logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).

lower.tail

logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise \(P[X > x]\).

n

number of random values to return.

p

vector of probabilities

Value

dt2 gives the density, pt2 gives the distribution function, qt2 gives the quantile function, and rt2 generates random deviates.

Details

This implementation of dt2 allows for automatic differentiation with RTMB.

$$f(x;\,\mu,\sigma,\nu) = \frac{1}{\sigma}\,f_t\!\left(\frac{x-\mu}{\sigma};\,\nu\right),$$ where \(f_t(\cdot;\nu)\) is the Student-\(t\) PDF with \(\nu\) degrees of freedom.

Examples

x <- rt2(1, 1, 2, 5)
d <- dt2(x, 1, 2, 5)
p <- pt2(x, 1, 2, 5)
q <- qt2(p, 1, 2, 5)