Student t distribution with location and scale
t2.RdDensity, distribution function, quantile function, and random generation for the t distribution with location and scale parameters.
Usage
dt2(x, mu, sigma, df, log = FALSE)
pt2(q, mu, sigma, df, lower.tail = TRUE, log.p = FALSE)
rt2(n, mu, sigma, df)
qt2(p, mu, sigma, df, lower.tail = TRUE, log.p = FALSE)
pt(q, df)Arguments
- x, q
vector of quantiles
- mu
location parameter
- sigma
scale parameter, must be positive.
- df
degrees of freedom, must be positive.
- log, log.p
logical; if
TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).- lower.tail
logical; if
TRUE(default), probabilities are \(P[X \le x]\), otherwise \(P[X > x]\).- n
number of random values to return.
- p
vector of probabilities
Value
dt2 gives the density, pt2 gives the distribution function, qt2 gives the quantile function, and rt2 generates random deviates.