| t2 | R Documentation |
Density, distribution function, quantile function, and random generation for the t distribution with location and scale parameters.
dt2(x, mu, sigma, df, log = FALSE)
pt2(q, mu, sigma, df)
rt2(n, mu, sigma, df)
qt2(p, mu, sigma, df)
pt(q, df)
x, q |
vector of quantiles |
mu |
location parameter |
sigma |
scale parameter, must be positive. |
df |
degrees of freedom, must be positive. |
log |
logical; if |
n |
number of random values to return. |
p |
vector of probabilities |
This implementation of dt2 allows for automatic differentiation with RTMB.
dt2 gives the density, pt2 gives the distribution function, qt2 gives the quantile function, and rt2 generates random deviates.
x <- rt2(1, 1, 2, 5)
d <- dt2(x, 1, 2, 5)
p <- pt2(x, 1, 2, 5)
q <- qt2(p, 1, 2, 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.