| zibeta | R Documentation |
Density, distribution function, and random generation for the zero-inflated beta distribution.
dzibeta(x, shape1, shape2, zeroprob = 0, log = FALSE)
pzibeta(q, shape1, shape2, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzibeta(n, shape1, shape2, zeroprob = 0)
x, q |
vector of quantiles |
shape1, shape2 |
non-negative shape parameters of the beta distribution |
zeroprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return. |
This implementation allows for automatic differentiation with RTMB.
dzibeta gives the density, pzibeta gives the distribution function, and rzibeta generates random deviates.
set.seed(123)
x <- rzibeta(1, 2, 2, 0.5)
d <- dzibeta(x, 2, 2, 0.5)
p <- pzibeta(x, 2, 2, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.