powered by
Density, distribution function, and random generation for the zero-inflated beta distribution.
dzibeta(x, shape1, shape2, zeroprob = 0, log = FALSE)pzibeta(q, shape1, shape2, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)rzibeta(n, shape1, shape2, zeroprob = 0)
pzibeta(q, shape1, shape2, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzibeta(n, shape1, shape2, zeroprob = 0)
dzibeta gives the density, pzibeta gives the distribution function, and rzibeta generates random deviates.
dzibeta
pzibeta
rzibeta
vector of quantiles
non-negative shape parameters of the beta distribution
zero-inflation probability between 0 and 1.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
number of random values to return.
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- rzibeta(1, 2, 2, 0.5) d <- dzibeta(x, 2, 2, 0.5) p <- pzibeta(x, 2, 2, 0.5)
Run the code above in your browser using DataLab