| zibeta2 | R Documentation |
Density, distribution function, and random generation for the zero-inflated beta distribution reparameterised in terms of mean and concentration.
dzibeta2(x, mu, phi, zeroprob = 0, log = FALSE)
pzibeta2(q, mu, phi, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzibeta2(n, mu, phi, zeroprob = 0)
x, q |
vector of quantiles |
mu |
mean parameter, must be in the interval from 0 to 1. |
phi |
concentration parameter, must be positive. |
zeroprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return. |
p |
vector of probabilities |
This implementation allows for automatic differentiation with RTMB.
dzibeta2 gives the density, pzibeta2 gives the distribution function, and rzibeta2 generates random deviates.
set.seed(123)
x <- rzibeta2(1, 0.5, 1, 0.5)
d <- dzibeta2(x, 0.5, 1, 0.5)
p <- pzibeta2(x, 0.5, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.