powered by
Density, distribution function, and random generation for the zero-inflated beta distribution reparameterised in terms of mean and concentration.
dzibeta2(x, mu, phi, zeroprob = 0, log = FALSE)pzibeta2(q, mu, phi, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)rzibeta2(n, mu, phi, zeroprob = 0)
pzibeta2(q, mu, phi, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzibeta2(n, mu, phi, zeroprob = 0)
dzibeta2 gives the density, pzibeta2 gives the distribution function, and rzibeta2 generates random deviates.
dzibeta2
pzibeta2
rzibeta2
vector of quantiles
mean parameter, must be in the interval from 0 to 1.
concentration parameter, must be positive.
zero-inflation probability between 0 and 1.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE (default), probabilities are \(P[X \le x]\), otherwise \(P[X > x]\).
number of random values to return.
vector of probabilities
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- rzibeta2(1, 0.5, 1, 0.5) d <- dzibeta2(x, 0.5, 1, 0.5) p <- pzibeta2(x, 0.5, 1, 0.5)
Run the code above in your browser using DataLab