powered by
Probability mass function, distribution function, and random generation for the zero-inflated binomial distribution.
dzibinom(x, size, prob, zeroprob = 0, log = FALSE)pzibinom(q, size, prob, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)rzibinom(n, size, prob, zeroprob = 0)
pzibinom(q, size, prob, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzibinom(n, size, prob, zeroprob = 0)
dzibinom gives the probability mass function, pzibinom gives the distribution function, and rzibinom generates random deviates.
dzibinom
pzibinom
rzibinom
vector of quantiles
number of trials (zero or more).
probability of success on each trial.
zero-inflation probability between 0 and 1
logical; return log-density if TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
TRUE
number of random values to return.
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- rzibinom(1, size = 10, prob = 0.5, zeroprob = 0.5) d <- dzibinom(x, size = 10, prob = 0.5, zeroprob = 0.5) p <- pzibinom(x, size = 10, prob = 0.5, zeroprob = 0.5)
Run the code above in your browser using DataLab