| zigamma | R Documentation |
Density, distribution function, and random generation for the zero-inflated gamma distribution.
dzigamma(x, shape, scale, zeroprob = 0, log = FALSE)
pzigamma(q, shape, scale, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rzigamma(n, shape, scale, zeroprob = 0)
x, q |
vector of quantiles |
shape |
positive shape parameter |
scale |
positive scale parameter |
zeroprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return |
This implementation allows for automatic differentiation with RTMB.
dzigamma gives the density, pzigamma gives the distribution function, and rzigamma generates random deviates.
x <- rzigamma(1, 1, 1, 0.5)
d <- dzigamma(x, 1, 1, 0.5)
p <- pzigamma(x, 1, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.