| zigamma2 | R Documentation |
Density, distribution function, and random generation for the zero-inflated gamma distribution reparameterised in terms of mean and standard deviation.
dzigamma2(x, mean = 1, sd = 1, zeroprob = 0, log = FALSE)
pzigamma2(q, mean = 1, sd = 1, zeroprob = 0)
rzigamma2(n, mean = 1, sd = 1, zeroprob = 0)
x, q |
vector of quantiles |
mean |
mean parameter, must be positive. |
sd |
standard deviation parameter, must be positive. |
zeroprob |
zero-inflation probability between 0 and 1. |
log |
logical; if |
n |
number of random values to return |
This implementation allows for automatic differentiation with RTMB.
dzigamma2 gives the density, pzigamma2 gives the distribution function, and rzigamma generates random deviates.
x <- rzigamma2(1, 2, 1, 0.5)
d <- dzigamma2(x, 2, 1, 0.5)
p <- pzigamma2(x, 2, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.