| ziinvgauss | R Documentation |
Density, distribution function, and random generation for the zero-inflated inverse Gaussian distribution.
dziinvgauss(x, mean = 1, shape = 1, zeroprob = 0, log = FALSE)
pziinvgauss(q, mean = 1, shape = 1, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rziinvgauss(n, mean = 1, shape = 1, zeroprob = 0)
x, q |
vector of quantiles |
mean |
location parameter |
shape |
shape parameter, must be positive. |
zeroprob |
zero-probability, must be in |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return |
This implementation of zidinvgauss allows for automatic differentiation with RTMB.
dziinvgauss gives the density, pziinvgauss gives the distribution function, and rziinvgauss generates random deviates.
x <- rziinvgauss(1, 1, 2, 0.5)
d <- dziinvgauss(x, 1, 2, 0.5)
p <- pziinvgauss(x, 1, 2, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.