| zilnorm | R Documentation |
Density, distribution function, and random generation for the zero-inflated log normal distribution.
dzilnorm(x, meanlog = 0, sdlog = 1, zeroprob = 0, log = FALSE)
pzilnorm(q, meanlog = 0, sdlog = 1, zeroprob = 0,
lower.tail = TRUE, log.p = FALSE)
rzilnorm(n, meanlog = 0, sdlog = 1, zeroprob = 0)
plnorm(q, meanlog = 0, sdlog = 1, lower.tail = TRUE, log.p = FALSE)
x, q |
vector of quantiles |
meanlog, sdlog |
mean and standard deviation of the distribution on the log scale with default values of 0 and 1 respectively. |
zeroprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return |
This implementation allows for automatic differentiation with RTMB.
dzilnorm gives the density, pzilnorm gives the distribution function, and rzilnorm generates random deviates.
x <- rzilnorm(1, 1, 1, 0.5)
d <- dzilnorm(x, 1, 1, 0.5)
p <- pzilnorm(x, 1, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.