| ziweibull | R Documentation |
Density, distribution function, and random generation for the zero-inflated Weibull distribution.
dziweibull(x, shape, scale, zeroprob = 0, log = FALSE)
pziweibull(q, shape, scale, zeroprob = 0, lower.tail = TRUE, log.p = FALSE)
rziweibull(n, shape, scale, zeroprob = 0)
x, q |
vector of quantiles |
shape |
positive shape parameter |
scale |
positive scale parameter |
zeroprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return |
This implementation allows for automatic differentiation with RTMB.
dziweibull gives the density, pziweibull gives the distribution function, and rziweibull generates random deviates.
x <- rziweibull(1, 1, 1, 0.5)
d <- dziweibull(x, 1, 1, 0.5)
p <- pziweibull(x, 1, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.