| zoibeta | R Documentation |
Density, distribution function, and random generation for the zero-one-inflated beta distribution.
dzoibeta(x, shape1, shape2, zeroprob = 0, oneprob = 0, log = FALSE)
pzoibeta(q, shape1, shape2, zeroprob = 0, oneprob = 0,
lower.tail = TRUE, log.p = FALSE)
rzoibeta(n, shape1, shape2, zeroprob = 0, oneprob = 0)
x, q |
vector of quantiles |
shape1, shape2 |
non-negative shape parameters of the beta distribution |
zeroprob |
zero-inflation probability between 0 and 1. |
oneprob |
zero-inflation probability between 0 and 1. |
log, log.p |
logical; if |
lower.tail |
logical; if |
n |
number of random values to return. |
This implementation allows for automatic differentiation with RTMB.
dzoibeta gives the density, pzoibeta gives the distribution function, and rzoibeta generates random deviates.
set.seed(123)
x <- rzoibeta(1, 2, 2, 0.2, 0.3)
d <- dzoibeta(x, 2, 2, 0.2, 0.3)
p <- pzoibeta(x, 2, 2, 0.2, 0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.