powered by
Density, distribution function, and random generation for the zero-one-inflated beta distribution.
dzoibeta(x, shape1, shape2, zeroprob = 0, oneprob = 0, log = FALSE)pzoibeta(q, shape1, shape2, zeroprob = 0, oneprob = 0, lower.tail = TRUE, log.p = FALSE)rzoibeta(n, shape1, shape2, zeroprob = 0, oneprob = 0)
pzoibeta(q, shape1, shape2, zeroprob = 0, oneprob = 0, lower.tail = TRUE, log.p = FALSE)
rzoibeta(n, shape1, shape2, zeroprob = 0, oneprob = 0)
dzoibeta gives the density, pzoibeta gives the distribution function, and rzoibeta generates random deviates.
dzoibeta
pzoibeta
rzoibeta
vector of quantiles
non-negative shape parameters of the beta distribution
zero-inflation probability between 0 and 1.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
number of random values to return.
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- rzoibeta(1, 2, 2, 0.2, 0.3) d <- dzoibeta(x, 2, 2, 0.2, 0.3) p <- pzoibeta(x, 2, 2, 0.2, 0.3)
Run the code above in your browser using DataLab