powered by
Density, distribution function, and random generation for the zero-one-inflated beta distribution reparameterised in terms of mean and concentration.
dzoibeta2(x, mu, phi, zeroprob = 0, oneprob = 0, log = FALSE)pzoibeta2(q, mu, phi, zeroprob = 0, oneprob = 0, lower.tail = TRUE, log.p = FALSE)rzoibeta2(n, mu, phi, zeroprob = 0, oneprob = 0)
pzoibeta2(q, mu, phi, zeroprob = 0, oneprob = 0, lower.tail = TRUE, log.p = FALSE)
rzoibeta2(n, mu, phi, zeroprob = 0, oneprob = 0)
dzoibeta2 gives the density, pzoibeta2 gives the distribution function, and rzoibeta2 generates random deviates.
dzoibeta2
pzoibeta2
rzoibeta2
vector of quantiles
mean parameter, must be in the interval from 0 to 1.
concentration parameter, must be positive.
zero-inflation probability between 0 and 1.
logical; if TRUE, probabilities/ densities \(p\) are returned as \(\log(p)\).
TRUE
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
number of random values to return.
This implementation allows for automatic differentiation with RTMB.
RTMB
set.seed(123) x <- rzoibeta2(1, 0.6, 2, 0.2, 0.3) d <- dzoibeta2(x, 0.6, 2, 0.2, 0.3) p <- pzoibeta2(x, 0.6, 2, 0.2, 0.3)
Run the code above in your browser using DataLab