dztnbinom gives the probability mass function, pztnbinom gives the distribution function, and rztnbinom generates random deviates.
Arguments
x, q
integer vector of counts
size
target for number of successful trials, or dispersion parameter (the shape parameter of the gamma mixing distribution). Must be strictly positive, need not be integer.
prob
probability of success in each trial. 0 < prob <= 1.
log, log.p
logical; return log-density if TRUE
lower.tail
logical; if TRUE, probabilities are \(P[X \le x]\), otherwise, \(P[X > x]\).
n
number of random values to return.
Details
This implementation allows for automatic differentiation with RTMB.
By definition, this distribution only has support on the positive integers (1, 2, ...).
Any zero-truncated distribution is defined as
$$P(X=x | X>0) = P(X=x) / (1 - P(X=0)),$$
where \(P(X=x)\) is the probability mass function of the corresponding untruncated distribution.