This implementation allows for automatic differentiation with RTMB.
By definition, this distribution only has support on the positive integers (1, 2, ...).
Any zero-truncated distribution is defined as
$$P(X=x | X>0) = P(X=x) / (1 - P(X=0)),$$
where \(P(X=x)\) is the probability mass function of the corresponding untruncated distribution.